@@ -7,7 +7,7 @@ from sanic.response import json
 __author__ = "Ahmed Nafies Okasha Mohamed <ahmed.nafies@gmail.com>"
 __copyright__ = "Copyright 2020, Ahmed Nafies Okasha Mohamed"
 __license__ = "MIT"
-__version__ = "1.0.0"
+__version__ = "1.2.0"
 
 
 BODY_METHODS = ["POST", "PUT", "PATCH"]
@@ -22,15 +22,16 @@ class InvalidOperation(Error):
     pass
 
 
-def validate(request, query, body):
+def validate(request, query, body, path):
 
     payload = None
     query_params = None
+    path_params = None
 
     if body and request.method not in BODY_METHODS:
         raise InvalidOperation(
             f"Http method '{request.method}' does not contain a payload,"
-            "yet a Pyndatic model for body was suppied"
+            "yet a `Pyndatic` model for body was supplied"
         )
 
     if body:
@@ -41,17 +42,24 @@ def validate(request, query, body):
         params = {k: v[0] for k, v in params.items()}
         query_params = query(**params).dict()
 
-    return dict(payload=payload, query=query_params)
+    if path:
+        path_params = path(**request.match_info).dict()
+
+    return dict(
+        payload=payload,
+        query=query_params,
+        **path_params if path_params else {},
+    )
 
 
-def webargs(query=None, body=None):
+def webargs(query=None, body=None, path=None):
     def decorator(f):
         @wraps(f)
         def decorated_function(request, *args, **kwargs):
             try:
-                result = validate(request, query, body)
+                result = validate(request, query, body, path)
             except ValidationError as e:
-                return json(e.errors())
+                return json(e.errors(), status=422)
             kwargs.update(result)
             if not asyncio.iscoroutinefunction(f):
                 response = f(request, *args, **kwargs)
